Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(663)

Unified Diff: components/scheduler/base/task_queue_manager.h

Issue 1411843008: Make blink platform time consistent with the timer virtual time (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix CachingCorrectnessTest Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/scheduler/base/task_queue_impl.cc ('k') | components/scheduler/base/task_queue_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/scheduler/base/task_queue_manager.h
diff --git a/components/scheduler/base/task_queue_manager.h b/components/scheduler/base/task_queue_manager.h
index 88737a336b76fc5d39ba6b22c179f6d2d84c1b98..002c4bc351a7d7fba8b4be655d326ce16f10bc42 100644
--- a/components/scheduler/base/task_queue_manager.h
+++ b/components/scheduler/base/task_queue_manager.h
@@ -100,8 +100,8 @@ class SCHEDULER_EXPORT TaskQueueManager
// Note |observer| is expected to outlive the SchedulerHelper.
void SetObserver(Observer* observer);
- // Returns the TickClock used by the TaskQueueManager.
- base::TickClock* tick_clock() const;
+ // Returns the delegate used by the TaskQueueManager.
+ const scoped_refptr<TaskQueueManagerDelegate>& delegate() const;
private:
friend class internal::LazyNow;
« no previous file with comments | « components/scheduler/base/task_queue_impl.cc ('k') | components/scheduler/base/task_queue_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698